\name{plots_grid}
\alias{rug_1d_grid}
\alias{points_1d_grid}
\alias{jitter_1d_grid}
\alias{density_1d_grid}
\alias{boxplot_1d_grid}
\alias{hist_1d_grid}
\alias{label_1d_grid}
\alias{arrow_1d_grid}
\alias{rect_1d_grid}
\alias{lines_1d_grid}
\alias{points_2d_grid}
\alias{density_2d_grid}
\alias{axes_2d_grid}
\alias{label_2d_grid}
\alias{arrow_2d_grid}
\alias{rect_2d_grid}
\title{Grid-Based Plotting Functions}
\description{
    The 1d and 2d plotting functions based on the \R package \pkg{grid}.
}
\usage{
rug_1d_grid(x, width=if(horizontal) 0.001 else 0.3,
            height=if(horizontal) 0.3 else 0.001, just="centre",
            col=par("fg"), horizontal=TRUE,
            default.units="npc", name="rug_1d", draw=TRUE, vp=NULL, ...)
points_1d_grid(x, horizontal=TRUE, plotAsp=0.1, plotID, turn,
               pch=21, size=unit(0.2 * if(horizontal) plotAsp else 1, "npc"),
               default.units="npc", name="points_1d", draw=TRUE, vp=NULL, ...)
jitter_1d_grid(x, cex=0.4, offset=0.25, horizontal=TRUE, plotAsp=0.1, plotID, turn,
               pch=21, size=unit(0.2 * if(horizontal) plotAsp else 1, "npc"),
               default.units="npc", name="jitter_1d", draw=TRUE, vp=NULL, ... )
density_1d_grid(x, density.args=list(), offset=0.25,
                method=c("single", "double"), horizontal=TRUE,
                default.units="npc", name="density_1d",
                draw=TRUE, vp=NULL, ...)
boxplot_1d_grid(x, horizontal=TRUE, plotAsp=0.1,
                plotID, turn, pch=21,
                size=unit(0.2 * if(horizontal) plotAsp else 1, "npc"),
                default.units="npc",
                col=NULL, lwd=2, bpwidth=0.5, range=NULL,
                name="boxplot_1d", draw=TRUE, vp=NULL, ...)
hist_1d_grid(x, offset=0.25, method=c("single", "double"),
             breaks=NULL, col=NULL, fill=NULL, horizontal=TRUE,
             default.units="npc", name="hist_1d",
             draw=TRUE, vp=NULL, ...)
label_1d_grid(loc.x=0.5, loc.y=0.5, label=NULL,
              x, horizontal=TRUE, plotID,
              just=c("centre", "centre"), rot=if(horizontal) 0 else 90, cex=0.4,
              check.overlap=FALSE, default.units="npc", name="label_1d",
              draw=TRUE, vp=NULL, ...)
arrow_1d_grid(loc=c(0.5, 0.5), length=0.5, angle=plotAsp*30,
              plotAsp=0.1, turn, default.units="npc", name="arrow_1d",
              draw=TRUE, vp=NULL, ...)
rect_1d_grid(loc.x=0.5, loc.y=0.5, horizontal=TRUE,
             width=if(horizontal) 1 else 0.4,
             height=if(horizontal) 0.4 else 1,
             just="centre", default.units="npc",
             name="rect_1d", draw=TRUE, vp=NULL, ...)
lines_1d_grid(loc.x=NULL, loc.y=NULL, horizontal=TRUE,
              default.units="npc", arrow=NULL,
              name="lines_1d", draw=TRUE, vp=NULL, ...)

points_2d_grid(x, type=c("p", "l", "o"), pch=NULL, size=NULL,
               default.units="npc", name=NULL, draw=TRUE, vp=NULL, ...)
density_2d_grid(x, ngrids=25, ccol=NULL, clwd=1, clty=1,
                xlim=c(0,1), ylim=c(0,1), plotID, turn,
                default.units="npc", name="density_2d", draw=TRUE, vp=NULL,
                ...)
axes_2d_grid(angle=30, length=unit(0.05, "npc"), type="open", eps=0.02,
             default.units="npc", name=NULL, draw=TRUE, vp=NULL, ...)
label_2d_grid(loc.x=0.96, loc.y=0.04, label=NULL,
              x, plotID,
              just=c("right", "bottom"), rot=0, cex=0.5,
              check.overlap=FALSE, default.units="npc",
              name="label_2d", draw=TRUE, vp=NULL, ...)
arrow_2d_grid(loc=c(0.5, 0.5), length=0.2, angle=30, turn,
              default.units="npc", name="arrow_2d", draw=TRUE, vp=NULL, ...)
rect_2d_grid(loc.x=0.5, loc.y=0.5, width=1, height=1, just="centre",
             default.units="npc", name="rect_2d", draw=TRUE, vp=NULL, ...)
}
\arguments{
    \item{x}{An \eqn{n}-\code{\link{vector}} (for 1d plots)
      or \eqn{(n,2)}-\code{\link{matrix}} (for 2d plots)
      containing the data. It is passed from \code{\link{zenplot}()}.}
    \item{width}{The rectangle width passed to \code{\link{grid.rect}()}.}
    \item{height}{The rectangle height passed to \code{\link{grid.rect}()}.}
    \item{just}{The justification (see \code{grid.rect()} for
      \code{rect_1d_grid()}, \code{rect_1d_grid()},
      \code{rect_1d_grid()} or \code{grid.text()} for
      \code{label_1d_grid()}, \code{label_2d_grid()}).}
    \item{horizontal}{A \code{\link{logical}} indicating whether the 1d plot
      is horizontal or vertical. It is passed
      from \code{\link{zenplot}()} (for 1d plots only).}
    \item{loc}{The location of the center of the arrow.}
    \item{loc.x,loc.y}{x-coordinates and y-coordinates of the points
      combined by lines (for \code{lines_1d_grid()}) or of the label
      (for \code{label_1d_grid()}, \code{label_2d_grid()})
      or of the center of the rectangle
      (for \code{rect_1d_grid()}, \code{rect_2d_grid()}).}
    \item{type}{The plot type.}
    \item{col}{For
      \describe{
	\item{\code{rug_1d_grid}:}{The color and fill color of the
	  rectangels forming the rugs.}
	\item{\code{boxplot_1d_grid}:}{The color of the box, whiskers
          and points.}
	\item{\code{hist_1d_grid}:}{The color of the bins.}
      }
    }
    \item{rot}{The rotation of the label in degrees.}
    \item{arrow}{See \code{\link{grid.lines}()}.}
    \item{density.args}{A \code{\link{list}()} of arguments for
      \code{\link{density}()}.}
    \item{offset}{A number in [0,0.5] determining the distance between the
      1d and 2d plots (for creating
      space between the two).}
    \item{method}{The type of plot used (\code{single} or \code{double}; the latter
      being reflected at the axis located in the middle of the 1d plot
      and pointing in the direction as given by \code{horizontal}).}
    \item{label}{The label to be used (with a useful default if
      \code{\link{NULL}}).}
    \item{plotID}{The plot identification passed on from
      \code{\link{zenplot}()}. This is a \code{\link{list}} containing
      the variable name(s), the column index(es) and the plotNo (among
      either all 1d or all 2d plots). It is passed
      from \code{\link{zenplot}()}.}
    \item{check.overlap}{See \code{\link{grid.text}()}.}
    \item{length}{The length of the arrow.}
    \item{angle}{The angle between the shaft and one of the edges of the
      arrow head.}
    \item{plotAsp}{The fraction (in [0,1]) of the shorter side divided by the
      longer side of the plot region. It is passed
      from \code{\link{zenplot}()} (for 1d plots only).}
    \item{cex}{The character expansion of the label.}
    \item{turn}{A \code{\link{character}} (in \code{"l"} (for \dQuote{left}),
      \code{"r"} (for \dQuote{right}), \code{"d"} (for \dQuote{down}),
      \code{"u"} (for \dQuote{up})) giving
      the turn as passed from \code{\link{zenplot}()}.}
    \item{pch}{The plot symbol for 2d plots.}
    \item{size}{The plot symbol size as passed to
      \code{\link{grid.points}()}.}
    \item{lwd}{The line width.}
    \item{bpwidth}{The width of the boxplot (in \code{default.units}).}
    \item{range}{Determines how far the plot whiskers extend out of the box. If
      \code{range=NULL}, this will be automatically determined depending
      on the sample size.}
    \item{breaks}{The break points for the histogram as passed to the
      underlying \code{\link{hist}()}. If \code{NULL}, the default is to
      use 20 equi-width bins covering the range of the data.}
    \item{fill}{The fill color of the bins.}
    \item{ngrids}{The number of grid points in each dimension (a scalar or
      an integer vector of length two).}
    \item{ccol, clwd, clty}{The colors (col), line widths (lwd) and line
      types (lty) of the contour lines. These can be single values or
      vectors (which are then recycled).}
    \item{eps}{The distance by which the axes are moved away from the plot region.}
    \item{xlim,ylim}{The x and y limits of the plotting region.}
    \item{default.units}{The default units passed to the underlying
      \pkg{grid} functions.}
    \item{name}{The character identifier for \pkg{grid} graphics.}
    \item{draw}{A \code{\link{logical}} indicating whether graphics output
      should be produced.}
    \item{vp}{The \code{\link{viewport}()}. It is passed
      from \code{\link{zenplot}()}.}
    \item{\dots}{Additional (graphical) parameters passed to
      \code{\link{gpar}()}.}
}
\value{
    An (invisibly) returned \code{\link{grob}}.
}
\details{
    These functions based on the \R package \pkg{grid} are provided as
    useful choices for the arguments \code{plot1d} and \code{plot2d} of
    \code{\link{zenplot}()}. See \code{\link{zenplot}()} how to use
    them, their source code for how to adjust them or how to write your
    own \code{plot1d} or \code{plot2d}. The main idea is that major
    arguments are passed to the underlying \pkg{grid} functions as
    formal arguments and the ellipsis argument is used to pass
    graphical paramaters (via \code{\link{gpar}()}). Hereby it is
    important to note that besides the ellipsis arguments (which are
    passed to both \code{plot1d} and \code{plot2d}),
    \code{\link{zenplot}()} passes further arguments to \code{plot1d} and
    \code{plot2d}. For \code{plot1d}, they are \code{x}, \code{horizontal},
    \code{plotAsp}, \code{plotID}, \code{turn} (as described above)
    and \code{vp} (the argument \code{vp1d} of
    \code{\link{zenplot}()}). For \code{plot2d}, they are \code{x},
    \code{plotID}, \code{turn} (as described above) and \code{vp}
    (the argument \code{vp2d} of \code{\link{zenplot}()}).
}
\author{Marius Hofert and Wayne Oldford}
%% \references{
%%   Hofert, M., Oldford, W. (2015). Zigzag Expanded Navigation Plots.
%%   \emph{} \bold{}(), --.
%% }
\seealso{
  \code{\link{zenplot}()} for how to use these functions.
  \link[=rug_1d_graphics]{plots_graphics} for similar functions based
  on the \R package \pkg{graphics}.
}
\examples{
## Implementation of 1d functions (for plot1d of zenplot())
rug_1d_grid
points_1d_grid
jitter_1d_grid
density_1d_grid
boxplot_1d_grid
label_1d_grid
arrow_1d_grid
rect_1d_grid
lines_1d_grid

## Implementation of 2d functions (for plot2d of zenplot())
points_2d_grid
density_2d_grid
label_2d_grid
arrow_2d_grid
rect_2d_grid
}
\keyword{dplot}